==> dmc-sdk-2.0.1.0-sources.jar: com/digiwin/dmc/sdk/entity/FileInfo.java <==
package com.digiwin.dmc.sdk.entity;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @author chenzwd
 * @date : 2018-07-04 16:01
 * @Description:
 */
public class FileInfo {

    private String id;

    private String fileName;

    private String contentType;

    private  Date uploadDate;

    private String extension;

    private String description;

    private String displayName;

    private long size;

    private long segmentTotalSize;

    private String directoryId;

    private Date lastModified;

    private String bucketName;

    private String tag;

    private boolean completed;

    private Map<String, Object> metadata =new HashMap<>();

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getContentType() {
        return contentType;
    }

    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    public Date getUploadDate() {
        return uploadDate;
    }

    public void setUploadDate(Date uploadDate) {
        this.uploadDate = uploadDate;
    }

    public String getExtension() {
        return extension;
    }

    public void setExtension(String extension) {
        this.extension = extension;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getDisplayName() {
        return displayName;
    }

    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }

    public long getSize() {
        return size;
    }

    public void setSize(long size) {
        this.size = size;
    }

    public long getSegmentTotalSize() {
        return segmentTotalSize;
    }

    public void setSegmentTotalSize(long segmentTotalSize) {
        this.segmentTotalSize = segmentTotalSize;
    }

    public String  getDirectoryId() {
        return directoryId;
    }

    public void setDirectoryId(String directoryId) {
        this.directoryId =  directoryId;
    }

    public Date getLastModified() {
        return lastModified;
    }

    public void setLastModified(Date lastModified) {
        this.lastModified = lastModified;
    }

    public String getBucketName() {
        return bucketName;
    }

    public void setBucketName(String bucketName) {
        this.bucketName = bucketName;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public boolean isCompleted() {
        return completed;
    }

    public void setCompleted(boolean completed) {
        this.completed = completed;
    }

    public Map<String, Object> getMetadata() {
        return metadata;
    }

    public void setMetadata(Map<String, Object> metadata) {
        this.metadata = metadata;
    }
}

==> dmc-sdk-4.0.0.0-sources.jar: com/digiwin/dmc/sdk/entity/FileInfo.java <==
package com.digiwin.dmc.sdk.entity;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @author chenzwd
 * @date : 2018-07-04 16:01
 * @Description:
 */
public class FileInfo {

    private String id;

    private String fileName;

    private String contentType;

    private  Date uploadDate;

    private String extension;

    private String description;

    private String displayName;

    private long size;

    private long segmentTotalSize;

    private String directoryId;

    private Date lastModified;

    private String bucketName;

    private String tag;

    private boolean completed;

    private Map<String, Object> metadata =new HashMap<>();

    private LocalDateTime expireDate;
    /** 租户id */
    private String tenantId;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getContentType() {
        return contentType;
    }

    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    public Date getUploadDate() {
        return uploadDate;
    }

    public void setUploadDate(Date uploadDate) {
        this.uploadDate = uploadDate;
    }

    public String getExtension() {
        return extension;
    }

    public void setExtension(String extension) {
        this.extension = extension;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getDisplayName() {
        return displayName;
    }

    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }

    public long getSize() {
        return size;
    }

    public void setSize(long size) {
        this.size = size;
    }

    public long getSegmentTotalSize() {
        return segmentTotalSize;
    }

    public void setSegmentTotalSize(long segmentTotalSize) {
        this.segmentTotalSize = segmentTotalSize;
    }

    public String  getDirectoryId() {
        return directoryId;
    }

    public void setDirectoryId(String directoryId) {
        this.directoryId =  directoryId;
    }

    public Date getLastModified() {
        return lastModified;
    }

    public void setLastModified(Date lastModified) {
        this.lastModified = lastModified;
    }

    public String getBucketName() {
        return bucketName;
    }

    public void setBucketName(String bucketName) {
        this.bucketName = bucketName;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public boolean isCompleted() {
        return completed;
    }

    public void setCompleted(boolean completed) {
        this.completed = completed;
    }

    public Map<String, Object> getMetadata() {
        return metadata;
    }

    public void setMetadata(Map<String, Object> metadata) {
        this.metadata = metadata;
    }

    public LocalDateTime getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(LocalDateTime expireDate) {
        this.expireDate = expireDate;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }
}
